#
# spec file for package safeeyes
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 Malcolm J Lewis <malcolmlewis@opensuse.org>
# Copyright (c) 2020 opensuse.lietuviu.kalba@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           safeeyes
Version:        2.2.3
Release:        1.3
Summary:        Tool for reminding the user to take breaks
License:        GPL-3.0-only
Group:          Productivity/Graphics/Visualization/Other
URL:            https://github.com/slgobinath/SafeEyes
Source0:        %{name}-%{version}.tar.xz
Source99:       safeeyes-rpmlintrc
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Babel
%if 0%{?suse_version} == 1500
BuildRequires:  python3-devel >= 3.6
%else
BuildRequires:  python3-devel >= 3.10
%endif
BuildRequires:  python3-psutil
BuildRequires:  python3-python-xlib
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
# MANUAL BEGIN
Requires:       python3-Babel
Requires:       python3-cairo >= 1.11.1
Requires:       python3-croniter
Requires:       python3-gobject
Requires:       python3-packaging
Requires:       python3-psutil
Requires:       python3-python-xlib
Requires:       typelib(AppIndicator3)
Requires:       typelib(Notify)
Recommends:     xprintidle
# MANUAL END
BuildArch:      noarch

%description
This utility reminds the user to take breaks whilst they are working
at the computer in an effort to alleviate eye strain (asthenopia).

%lang_package

%prep
%setup -q
#Fix rpm runtime dependency rpmlint error replace the shebang in all the scripts with %%{_bindir}/python3
find . -type f -exec perl -pi -e 'BEGIN{undef $/};s[^#\!/usr/bin/env python3][#\!%{_bindir}/python3]' {} \;
find . -type f -exec perl -pi -e 'BEGIN{undef $/};s[^#\!/usr/bin/env python][#\!%{_bindir}/python3]' {} \;
# SmartPause: Increase default idle time to pause SafeEyes
sed 's/"default": 5,/"default": 60,/' -i safeeyes/plugins/smartpause/config.json
%if 0%{?suse_version} == 1500
%autopatch -p1
%endif

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# localization
%find_lang %{name}

%files
%doc README.md
%license LICENSES/GPL-3.0-or-later.txt
%{_bindir}/safeeyes
%{_datadir}/applications/io.github.slgobinath.SafeEyes.desktop
%{_datadir}/icons/hicolor/*/*/
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%exclude %{python3_sitelib}/%{name}/config/locale

%files lang -f %{name}.lang
%dir %{python3_sitelib}/%{name}/config/locale
%dir %{python3_sitelib}/%{name}/config/locale/*
%dir %{python3_sitelib}/%{name}/config/locale/*/LC_MESSAGES

%changelog
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 2.2.3:
  * Translations
  * Make config and stylesheet files non-executable
  * Retry loading trayicon plugin to fix races on startup
  * Fix "Show next break time in tray icon" for desktops support tray icons
    with labels
  * Fix next break time in tray icon when disabling SafeEyes
  * Make SafeEyes compatible with Python 3.6 again
  * Add 'hyprland' to the list of recognized desktop sessions
  * Remove hard dependency on X11
- Drop SafeEyes-Python3.6-compatibility.patch
* Sat Oct 19 2024 <opensuse.lietuviu.kalba@gmail.com>
- Update SafeEyes-Python3.6-compatibility.patch according PEP 584
  recommendations.
* Sun Oct 13 2024 <opensuse.lietuviu.kalba@gmail.com>
- Add SafeEyes-Python3.6-compatibility.patch fix to use in Python 3.6
  for openSUSE Leap 15.*, because SafeEyes itself needs Python 3.10+.
- Add missed python3-packaging dependency, see bsc#1227743 and
  gh#slgobinath/SafeEyes#467
* Wed Aug  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.2.2:
  * Fixed translations
  * Fixed GTK startup error
  * Fixed frozen break screen if safeeyes is closed right before a break
  * Fixed safeeyes not working if stylesheet is missing
  * Replaced "tightly close your eyes" with "gently close your eyes"
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.2.1:
  * Make limit consecutive skips to default
  * Add list of contributors to About page
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.2.0:
  * Limit consecutive skips
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.1.9:
  * Fix crash in smartpause
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.1.8:
  * New version with python 3.12 support
* Wed Jul  5 2023 Michael Vetter <mvetter@suse.com>
- Update to version 2.1.6:
  * Reverse-DNS scheme for icons & Broken initialize logic fix & Add appstream (#519)
  * Display a traceback of plugin loading errors when --debug is given (#506)
  * Remove executable permission from safeeyes.desktop (#512)
  * Fix incorrectly skipped long breaks (#443)
  * Take short or long breaks from tray (#347)
  * Add sub-menu to take any, short or long breaks
  * Update translations
* Thu Dec 22 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.1.4:
  * Simplify Debian installation instructions
  * Ayatana Appindicator library
  * Add smartpause support for swaywm
  * Directly track running swayidle process
  * Use HTTPS where users potentially open the URL in a browser
  * check if using wayland via WAYLAND_DISPLAY env variable
  * add support for python without gettext.bindtextdomain
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.1.3:
  * Detect full screen in Wayland
  * Added translations for brazilian Portugues
  * Fixed: No break can be triggered if no long breaks are configured
* Sat Mar 27 2021 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing in descriptions. Trim redundant metadata
  and tone down program claims.
* Wed Mar 24 2021 antoine.belvire@opensuse.org
- Update to version 2.1.2:
  * Fix missing icons (gh#slgobinath/SafeEyes#420,
    gh#slgobinath/SafeEyes#406).
  * Fix breaks getting postponed forever
    (gh#slgobinath/SafeEyes#410).
  * Fix unable to disable auto-start (gh#slgobinath/SafeEyes#409).
  * Random break order (gh#slgobinath/SafeEyes#418).
- Changes from version 2.1.1:
  * Fix desktop entry creation.
- Changes from version 2.1.0:
  * Option to disable RPC server.
  * Add scroll bar to Settings dialog.
  * Fix idle start time calculation.
  * Add cron expression to Health Stats plugin.
  * Fix Gnome restarting in Ubuntu 20.10.
  * Drop support to Python 3.4 and add support to 3.8 and 3.9.
- Remove SafeEyes-fix-install-path.patch: Fixed upstream.
- Add new runtime dependency on python3-cronie.
- Remove unused build dependency on fdupes.
- Clean spec file.
* Thu Oct 22 2020 opensuse.lietuviu.kalba@gmail.com
- SmartPause plugin: Increase default idle time to pause SafeEyes.
* Tue Oct 13 2020 tuukka.pasanen@ilmi.fi
- Update to version 20201003.448e11f:
  * Fix UnboundLocalError in smartpause plugin (#378)
  * Add installation instruction for openSUSE Tumbleweed, resolve #376 (#377)
  * Translated using Weblate (Swedish)
* Sun Sep 27 2020 opensuse.lietuviu.kalba@gmail.com
- Add python3-cairo and python3-gobject as runtime dependencies.
* Sun Sep 20 2020 opensuse.lietuviu.kalba@gmail.com
- Update to 2.0.9 + git a3b957d (2020-09-06):
  - Updated translations: Arabic, Chinese (Traditional)),
    Lithuanian, Marathi.
* Mon Aug 24 2020 opensuse.lietuviu.kalba@gmail.com
- Update to 2.0.9 + git 0462a41 (2020-08-20)
- Changes after 2.0.9:
  - new translations or translation updates after 2.0.9 release
- Changes from 2.0.8 to 2.0.9
  - New Settings dialog
  - Move to Gtk 3.12
  - Improved Health Stats plugin
  - Blink tray icon after pre-break notification
- Changes from 2.0.6 to 2.0.8
  - Action buttons support is added to the break screen
  - Option to postpone the next break until the system becomes idle
- Changes from 2.0.4 to 2.0.6
  - Audible alert before breaks (Enabled by default)
  - Do not disturb while on battery (Disabled by default)
  - Skip long break if the user is idle for a long time
- Changes from 2.0.0 to 2.0.4
  - Various bug fixes and translation updates, see
    https://github.com/slgobinath/SafeEyes/releases for more details
- Drop SafeEyes-fix-python-requires.patch
* Thu Nov  2 2017 malcolmlewis@opensuse.org
- Update to version 2.0.0 + git fd4882b (2017-10-28).
- Add rpmlintrc to suppress warnings.
- Add script to pull from git.
- Add SafeEyes-fix-python-requires.patch: Define python3-xlib in
  setup.py requires.
- Drop SafeEyes-fix-desktop-file.patch.
* Mon Feb 27 2017 malcolmlewis@opensuse.org
- Initial build.
- Add SafeEyes-fix-desktop-file.patch: Cleanup desktop file
  errors.
